@@ -5,7 +5,7 @@ from datetime import datetime, timedelta
 
 import pandas as pd
 from notecoin.base.database.lanzou import LanzouDirectory
-from notecoin.coins.base.load import LoadDataKline
+from notecoin.coins.base.load import LoadDataKline, LoadTradeKline
 from notecoin.utils.time import day_during, month_during, week_during
 from notefile.compress import tarfile
 
@@ -13,7 +13,6 @@ logger = logging.getLogger()
 
 
 def merge_unique(input_csv_list, put_csv, tail_size=100000):
-
     for i, csv_file in enumerate(input_csv_list):
         if i == 0:
             df = pd.read_csv(csv_file)
@@ -72,6 +71,7 @@ class DataFileProperty:
     def __init__(self, exchange, data_type='kline', path='~/workspace/tmp', start_date=datetime.today(),
                  end_date=datetime.today(), freq='daily', timeframe='1m', file_format='%Y%m%d'):
         self.exchange = exchange
+        self.data_type = data_type
         self.file_pro = FileProperty(exchange_name=exchange.name.lower(), path=path, freq=freq,
                                      data_type=data_type, timeframe=timeframe, start_date=start_date, end_date=end_date,
                                      file_format=file_format)
@@ -79,6 +79,12 @@ class DataFileProperty:
 
     def change_freq(self, freq):
         self.file_pro.freq = freq
+    
+    def change_data_type(self, data_type):
+        self.file_pro.data_type = data_type
+    
+    def change_timeframe(self, timeframe):
+        self.file_pro.timeframe = timeframe
 
     def sync(self, path):
         logger.info('sync file')
@@ -97,7 +103,10 @@ class DataFileProperty:
         self.sync(self.file_pro.path)
 
         logger.info(f'download for {file_pro.file_path_tar(absolute=False)}')
-        exchan = LoadDataKline(self.exchange)
+        if self.data_type == 'kline':
+            exchan = LoadDataKline(self.exchange)
+        else:
+            exchan = LoadTradeKline(self.exchange)
         exchan.table.delete_all()
         unix_start, unix_end = int(file_pro.start_date.timestamp() * 1000), int(file_pro.end_date.timestamp() * 1000)
         # 下载
