@@ -3,9 +3,10 @@ import logging
 import time
 from datetime import datetime
 
+import ccxt  # noqa: E402
 import pandas as pd
 from ccxt.base.exchange import Exchange
-from notecoin.base.database import KlineData
+from notecoin.base.database import KlineData, TradeData
 from tqdm import tqdm
 
 logger = logging.getLogger()
@@ -50,8 +51,8 @@ class LoadDataKline:
         unix_end = unix_end
         unix_max = unix_max or unix_end
         unix_min = unix_min or unix_end
-        #print(unix_start, unix_end, unix_max, unix_max)
-        if abs((unix_max-unix_min)/unix_delta) > 100:
+        # print(unix_start, unix_end, unix_max, unix_max)
+        if abs((unix_max - unix_min) / unix_delta) > 100:
             if unix_min >= unix_start:
                 unix_temp = unix_min
                 pbar = tqdm(range(unix_min, unix_start, -unix_delta), desc=symbol)
@@ -86,3 +87,53 @@ class LoadDataKline:
                     if status is False:
                         break
                     unix_temp = result[-1][0]
+
+
+class LoadTradeKline:
+    def __init__(self, exchange: Exchange, suffix="com", *args, **kwargs):
+        self.table = TradeData(prefix=exchange.name, suffix=suffix)
+        self.exchange = exchange
+        super(LoadTradeKline, self).__init__(*args, **kwargs)
+
+    def load_all(self, *args, **kwargs):
+        self.exchange.load_markets()
+        for sym in tqdm(self.exchange.symbols):
+            if ':' not in sym:
+                self.load(sym, *args, **kwargs)
+
+    def load(self, symbol, unix_start, unix_end, *args, **kwargs):
+        one_hour = 3600 * 1000
+        since = unix_start
+        previous_trade_id = None
+        while since < unix_end:
+            try:
+                trades = self.exchange.fetch_trades(symbol, since)
+
+                if len(trades) == 0:
+                    since += one_hour
+                    continue
+
+                last_trade = trades[-1]
+                if previous_trade_id == last_trade['id']:
+                    since += one_hour
+                    continue
+
+                since = last_trade['timestamp']
+                previous_trade_id = last_trade['id']
+
+                result = []
+                for trade in trades:
+                    result.append({
+                        'symbol': trade['symbol'],
+                        'id': trade['id'],
+                        'timestamp': trade['timestamp'],
+                        'type': trade['type'],
+                        'side': trade['side'],
+                        'price': trade['price'],
+                        'amount': trade['amount'],
+                    })
+                self.table.insert(result)
+                time.sleep(int(self.exchange.rateLimit / 1000))
+            except ccxt.NetworkError as e:
+                print(type(e).__name__, str(e))
+                self.exchange.sleep(10000)
